%%
%% This is file `mik.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `MIK')
%% This file is a generated file from the sources of the `cyrillic' bundle
%% in the LaTeX2e distribution.
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs/
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% Copyright 1993-2019
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the Standard LaTeX `Cyrillic Bundle'.
%% -----------------------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% `Cyrillic Bundle'. You may however distribute the LaTeX `Cyrillic
%% Bundle' without such generated files.
%% 
%% The list of all files belonging to the `Cyrillic Bundle' is
%% given in the file `manifest.txt'.
%% 
% (C) Copyright 1999 by Georgi Boshnakov, Guentcho Skordev.
\ProvidesFile{mik.def}
  [2022/06/11 v1.0e Input encoding file]
\makeatletter
\ProvideTextCommandDefault{\textblacksquare}
  {\vrule \@width .3em \@height .4em \@depth -.1em\relax}
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\providecommand{\mathtwosuperior}{{^2}}
\providecommand{\mathnsuperior}{{^n}}
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRZH}
\DeclareInputText{135}{\CYRZ}
\DeclareInputText{136}{\CYRI}
\DeclareInputText{137}{\CYRISHRT}
\DeclareInputText{138}{\CYRK}
\DeclareInputText{139}{\CYRL}
\DeclareInputText{140}{\CYRM}
\DeclareInputText{141}{\CYRN}
\DeclareInputText{142}{\CYRO}
\DeclareInputText{143}{\CYRP}
\DeclareInputText{144}{\CYRR}
\DeclareInputText{145}{\CYRS}
\DeclareInputText{146}{\CYRT}
\DeclareInputText{147}{\CYRU}
\DeclareInputText{148}{\CYRF}
\DeclareInputText{149}{\CYRH}
\DeclareInputText{150}{\CYRC}
\DeclareInputText{151}{\CYRCH}
\DeclareInputText{152}{\CYRSH}
\DeclareInputText{153}{\CYRSHCH}
\DeclareInputText{154}{\CYRHRDSN}
\DeclareInputText{155}{\CYRERY}
\DeclareInputText{156}{\CYRSFTSN}
\DeclareInputText{157}{\CYREREV}
\DeclareInputText{158}{\CYRYU}
\DeclareInputText{159}{\CYRYA}
\DeclareInputText{160}{\cyra}
\DeclareInputText{161}{\cyrb}
\DeclareInputText{162}{\cyrv}
\DeclareInputText{163}{\cyrg}
\DeclareInputText{164}{\cyrd}
\DeclareInputText{165}{\cyre}
\DeclareInputText{166}{\cyrzh}
\DeclareInputText{167}{\cyrz}
\DeclareInputText{168}{\cyri}
\DeclareInputText{169}{\cyrishrt}
\DeclareInputText{170}{\cyrk}
\DeclareInputText{171}{\cyrl}
\DeclareInputText{172}{\cyrm}
\DeclareInputText{173}{\cyrn}
\DeclareInputText{174}{\cyro}
\DeclareInputText{175}{\cyrp}
\DeclareInputText{176}{\cyrr}
\DeclareInputText{177}{\cyrs}
\DeclareInputText{178}{\cyrt}
\DeclareInputText{179}{\cyru}
\DeclareInputText{180}{\cyrf}
\DeclareInputText{181}{\cyrh}
\DeclareInputText{182}{\cyrc}
\DeclareInputText{183}{\cyrch}
\DeclareInputText{184}{\cyrsh}
\DeclareInputText{185}{\cyrshch}
\DeclareInputText{186}{\cyrhrdsn}
\DeclareInputText{187}{\cyrery}
\DeclareInputText{188}{\cyrsftsn}
\DeclareInputText{189}{\cyrerev}
\DeclareInputText{190}{\cyryu}
\DeclareInputText{191}{\cyrya}
\DeclareInputText{213}{\textnumero}
\DeclareInputText{214}{\S}
\DeclareInputMath{224}{\alpha}
\DeclareInputMath{225}{\beta}
\DeclareInputMath{226}{\Gamma}
\DeclareInputMath{227}{\pi}
\DeclareInputMath{228}{\Sigma}
\DeclareInputMath{229}{\sigma}
\DeclareInputMath{230}{\mu}
\DeclareInputMath{231}{\tau}
\DeclareInputMath{232}{\Phi}
\DeclareInputMath{233}{\Theta}
\DeclareInputMath{234}{\Omega}
\DeclareInputMath{235}{\delta}
\DeclareInputMath{236}{\infty}
\DeclareInputMath{237}{\emptyset}
\DeclareInputMath{238}{\in}
\DeclareInputMath{239}{\cap}
\DeclareInputMath{240}{\equiv}
\DeclareInputMath{241}{\pm}
\DeclareInputMath{242}{\geq}
\DeclareInputMath{243}{\leq}
\DeclareInputMath{246}{\div}
\DeclareInputMath{247}{\sim}
\DeclareInputText{248}{\textdegree}
\DeclareInputText{249}{\textbullet}
\DeclareInputText{250}{\textperiodcentered}
\DeclareInputMath{251}{\surd}
\DeclareInputMath{252}{\mathnsuperior}
\DeclareInputMath{253}{\mathtwosuperior}
\DeclareInputText{254}{\textblacksquare}
\DeclareInputText{255}{\nobreakspace}
\makeatother
\endinput
%%
%% End of file `mik.def'.
